@@ -27,7 +27,7 @@ class FolderArchiver(ZipArchiver):
         for path, rel in walk_folders(imap(os.path.abspath, items)):
             try:
                 cb(path, rel)
-                yield ((path,), {'arcname': rel.encode('utf-8')})
+                yield ((path,), {'arcname': rel})
             except Exception as e:
                 if not hasattr(e, 'filename'):
                     setattr(e, 'filename', path)
